# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'MapResult',
    'AwaitableMapResult',
    'map',
    'map_output',
]

@pulumi.output_type
class MapResult:
    def __init__(__self__, result=None):
        if result and not isinstance(result, dict):
            raise TypeError("Expected argument 'result' to be a dict")
        pulumi.set(__self__, "result", result)

    @property
    @pulumi.getter
    def result(self) -> Mapping[str, Any]:
        return pulumi.get(self, "result")


class AwaitableMapResult(MapResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return MapResult(
            result=self.result)


def map(args: Optional[Sequence[Any]] = None,
        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableMapResult:
    """
    Returns a map consisting of the key/value pairs specified as arguments.
    """
    __args__ = dict()
    __args__['args'] = args
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('std:index:map', __args__, opts=opts, typ=MapResult).value

    return AwaitableMapResult(
        result=pulumi.get(__ret__, 'result'))


@_utilities.lift_output_func(map)
def map_output(args: Optional[pulumi.Input[Sequence[Any]]] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[MapResult]:
    """
    Returns a map consisting of the key/value pairs specified as arguments.
    """
    ...
